CMB constraints
===============

Overview
--------

The ``Theory`` class contains functions for computing CMB limits and
:math:`f_{\mathrm{eff}}` for dark matter models. Other useful constants and
functions are also available.

Computing CMB limits
--------------------

.. automethod:: hazma.theory.Theory.cmb_limit

Functions and constants
-----------------------

.. automethod:: hazma.theory.Theory.f_eff

.. autodata:: hazma.cmb.p_ann_planck_temp_pol

.. autodata:: hazma.cmb.p_ann_planck_temp_pol_lensing

.. autodata:: hazma.cmb.p_ann_planck_temp_pol_lensing_bao

.. autofunction:: hazma.cmb.vx_cmb
